@@ -8,7 +8,7 @@ from .fields import (  # noqa
 )
 from .forms import ImporterModelForm  # noqa
 from .parsers import BaseImportParser, TablibCSVImportParser, TablibXLSXImportParser  # noqa
-from .resultset import ImportResultRow, ImportResultSet
+from .resultset import ImportResultRow, ImportResultSet  # noqa
 from .widgets import CompositeLookupWidget  # noqa
 
-__version__ = '0.4.6'
+__version__ = '0.4.15'
