@@ -3,6 +3,7 @@ from django.db.models.fields import NOT_PROVIDED
 from django.forms import modelform_factory
 
 from .caches import SimpleDictCache
+from .fields import FlatRelatedField
 from .resultset import ImportResultSet
 
 
@@ -54,9 +55,13 @@ class ModelImporter:
             form=self.modelimportformclass,
             fields=fields,
         )
+        # Remove fields altogether if they haven't been specified in the import (makes sense for updates). #houseofcards..
         base_fields_to_del = set(klass.base_fields.keys()) - set(fields)
         for f in base_fields_to_del:
-            del klass.base_fields[f]
+            # NOTE: FlatRelatedFields already behave well for partial imports. Popping this top layer
+            # would cause updates to ignore them altogether..
+            if not isinstance(klass.base_fields[f], FlatRelatedField):
+                del klass.base_fields[f]
         return klass
 
     @transaction.atomic
@@ -101,6 +106,7 @@ class ModelImporter:
         created = updated = skipped = failed = 0
         for i, row in enumerate(rows, start=1):
             errors = []
+            warnings = []
             instance = None
             to_be_created = row.get('id', '') == ''  # If ID is blank we are creating a new row, otherwise we are updating
             to_be_updated = not to_be_created
@@ -141,10 +147,12 @@ class ModelImporter:
                     # TODO: Filter out errors associated with FlatRelatedField
                     errors = list(form.errors.items())
 
+                warnings = list(form.warnings.items())
+
             if not instance or not instance.pk:
                 failed += 1
 
-            result_row = importresult.append(i, row, errors, instance, to_be_created)
+            result_row = importresult.append(i, row, errors, instance, to_be_created, warnings)
             if progress_logger:
                 progress_logger(result_row)
 
